@@ -1,7 +1,7 @@
 "plot.rasch" <-
-function (x, type = c("ICC", "IIC"), items = NULL, zrange = c(-3.8, 3.8), annot, labels = NULL, 
-                        legend = FALSE, cx = "topleft", cy = NULL, ncol = 1, bty = "n", col = palette(), lty = 1, 
-                        pch, xlab, ylab, main, sub = NULL, cex = par("cex"), cex.lab = par("cex.lab"), 
+function (x, type = c("ICC", "IIC"), items = NULL, z = seq(-3.8, 3.8, length = 100), annot, 
+                        labels = NULL, legend = FALSE, cx = "topleft", cy = NULL, ncol = 1, bty = "n", col = palette(), 
+                        lty = 1, pch, xlab, ylab, main, sub = NULL, cex = par("cex"), cex.lab = par("cex.lab"), 
                         cex.main = par("cex.main"), cex.sub = par("cex.sub"), cex.axis = par("cex.axis"), ...) {
     if (!inherits(x, "rasch"))
         stop("Use only with 'rasch' objects.\n")
@@ -18,8 +18,7 @@ function (x, type = c("ICC", "IIC"), items = NULL, zrange = c(-3.8, 3.8), annot,
         items
     } else
         1:p
-    z1 <- seq(zrange[1], zrange[2], length = 100)
-    Z <- cbind(1, z1)
+    Z <- cbind(1, z)
     pr <- if (type == "ICC") {
         plogis(Z %*% t(betas))
     } else {
@@ -46,7 +45,7 @@ function (x, type = c("ICC", "IIC"), items = NULL, zrange = c(-3.8, 3.8), annot,
         ylab <- if (type == "ICC") "Probability" else "Information"
     }
     r <- if (type == "ICC") c(0, 1) else { if (plot.info) range(rowSums(pr)) else range(pr[, itms]) }
-    plot(zrange, r, type = "n", xlab = xlab, ylab = ylab, main = main, sub = sub, cex = cex, cex.lab = cex.lab, 
+    plot(range(z), r, type = "n", xlab = xlab, ylab = ylab, main = main, sub = sub, cex = cex, cex.lab = cex.lab, 
             cex.main = cex.main, cex.axis = cex.axis, cex.sub = cex.sub, ...)
     if (missing(annot)) {
         annot <- !legend
@@ -74,15 +73,15 @@ function (x, type = c("ICC", "IIC"), items = NULL, zrange = c(-3.8, 3.8), annot,
     }
     if (plot.items) {
         for (it in seq(along = itms)) {
-            lines(z1, pr[, itms[it]], lty = lty[it], col = col[it], ...)
+            lines(z, pr[, itms[it]], lty = lty[it], col = col[it], ...)
             if (!missing(pch))
-                points(z1[pch.ind], pr[pch.ind, itms[it]], pch = pch[it], col = col[it], cex = cex, ...)
+                points(z[pch.ind], pr[pch.ind, itms[it]], pch = pch[it], col = col[it], cex = cex, ...)
             if (annot)
-                text(z1[pos[it]], pr[pos[it], itms[it]], labels = nams[it], adj = c(0, 2), col = col[it], cex = cex, ...)
+                text(z[pos[it]], pr[pos[it], itms[it]], labels = nams[it], adj = c(0, 2), col = col[it], cex = cex, ...)
         }
     }
     if (plot.info)
-        lines(z1, rowSums(pr), lty = lty, col = col, ...)
-    invisible(if (plot.items) cbind(z = z1, pr[, itms]) else cbind(z = z1, info = rowSums(pr)))
+        lines(z, rowSums(pr), lty = lty, col = col, ...)
+    invisible(if (plot.items) cbind(z = z, pr[, itms]) else cbind(z = z, info = rowSums(pr)))
 }
 
