@@ -10,18 +10,20 @@ function (x, digits = 2, ...) {
         out <- diag(rep("-", x$nitems))
         out[lower.tri(out)] <- format(sapply(x$margins, "[[", "TotalResid"), digits = digits, nsmall = 2)
         out <- t(out)
-        out[lower.tri(out)] <- sapply(x$margins, function (x) if(x$TotalResid > x$rule) "***" else "")
+        out[lower.tri(out)] <- sapply(x$margins, function (x) if (x$TotalResid > x$rule) "***" else "")
         dimnames(out) <- list(x$names, x$names)
         print(noquote(out))
-        cat("\n'***' denotes pairs of items with lack-of-fit\n")
+        if (any(out == "***"))
+            cat("\n'***' denotes pairs of items with lack-of-fit\n")
     } else {
         cat("\nFit on the Three-Way Margins\n\n")
         out <- data.frame(combinations(x$nitems, 3))
         names(out) <- c("Item i", "Item j", "Item k")
         out$"(O-E)^2/E" <- round(sapply(x$margins, "[[", "TotalResid"), digits = 2)
-        out$" " <- sapply(x$margins, function (x) if(x$TotalResid > x$rule) "***" else "")
+        out$" " <- sapply(x$margins, function (x) if (x$TotalResid > x$rule) "***" else "")
         print(out)
-        cat("\n'***' denotes triplets of items with lack-of-fit\n")
+        if (any(out == "***"))
+            cat("\n'***' denotes pairs of items with lack-of-fit\n")
     }
     cat("\n")
     invisible(x)
