@@ -1,7 +1,8 @@
 "rmvlogis" <-
-function (n, thetas, guessing = FALSE, distr = c("normal", "logistic")) {
+function (n, thetas, guessing = FALSE, link = c("logit", "probit"), distr = c("normal", "logistic")) {
     if (!is.matrix(thetas))
         stop("'thetas' must be a matrix with rows representing the items.\n")
+    link <- match.arg(link)
     distr <- match.arg(distr)
     z <- if (distr == "normal") cbind(1, rnorm(n)) else cbind(1, rlogis(n))
     p <- nrow(thetas)
@@ -11,9 +12,9 @@ function (n, thetas, guessing = FALSE, distr = c("normal", "logistic")) {
         betas <- thetas[, 1:2]
         cs <- thetas[, 3]
         cs.mat <- matrix(cs, n, p, TRUE)
-        cs.mat + (1 - cs.mat) * plogis(z %*% t(betas))
+        cs.mat + (1 - cs.mat) * if (link == "logit") plogis(z %*% t(betas)) else pnorm(z %*% t(betas))
     } else {
-        plogis(z %*% t(thetas))
+        if (link == "logit") plogis(z %*% t(thetas)) else pnorm(z %*% t(thetas))
     }
     X <- matrix(0, n, p)
     for (i in 1:p)
